import unittest
import pycodestyle


class TestCodeFormat(unittest.TestCase):

    def test_conformance(self):
        """Test that we conform to PEP-8."""
        style = pycodestyle.StyleGuide(quiet=True)
        # style.
        style.input_dir('algorithms')
        style.input_dir('base')
        result = style.check_files()
        assert result.total_errors == 0



import pytest

import pydp as pd


class TestStatus():
    def test_hello(self):
        i = 1
        assert 1 == i

    def test_status_codes(self):
        status_code_available = [
            "StatusCode.kOk",
            "StatusCode.kCancelled",
            "StatusCode.kUnknown",
            "StatusCode.kInvalidArgument",
            "StatusCode.kDeadlineExceeded",
            "StatusCode.kNotFound",
            "StatusCode.kAlreadyExists",
            "StatusCode.kPermissionDenied",
            "StatusCode.kResourceExhausted",
            "StatusCode.kFailedPrecondition",
            "StatusCode.kAborted",
            "StatusCode.kOutOfRange",
            "StatusCode.kUnimplemented",
            "StatusCode.kInternal",
            "StatusCode.kUnavailable",
            "StatusCode.kDataLoss",
            "StatusCode.kUnauthenticated",
        ]
        actual_codes = []
        x = range(17)
        for n in x:
            actual_codes.append(str(pd.Status.StatusCode(n)))
        print(actual_codes)
        assert status_code_available == actual_codes

    def test_code_to_string(self):
        s = pd.Status.status_code_to_string(pd.Status.StatusCode(3))
        assert s == "kInvalidArgument"


class TestSampleLoad():
    def test_payload_test(self):
        # when status code is OK, no appending is done to the status object
        s = pd.Status(pd.Status.StatusCode(0), "New status object")
        url = "http://test.com"
        payload_content = "example payload content"
        s.set_payload(url, payload_content)
        assert s.get_payload(url) is None

    def test_payload_test_1(self):
        # in all Status code except 0, payload is added
        s = pd.Status(pd.Status.StatusCode(1), "New status object")
        url = "http://test.com"
        payload_content = "example payload content"
        s.set_payload(url, payload_content)
        assert s.get_payload(url) == payload_content

    def test_erase_payload(self):
        s = pd.Status(pd.Status.StatusCode(0), "New status object")
        url = "http://test.com"
        payload_content = "example payload content"
        s.set_payload(url, payload_content)
        s.erase_payload(url)
        assert s.get_payload(url) is None



import pytest
import pydp as pd


class TestLogging():
    def test_logging(self):
        directory = 'tests'
        vlog_level = 3
        success = pd.Logging(directory, 'log_test', vlog_level)
        assert success is True

    def test_logging1(self):
        directory = ''
        vlog_level = 3
        success = pd.Logging(
            directory, 'log_test.txt', vlog_level)
        assert success is False

    def test_logging2(self):
        directory = 'tests'
        vlog_level = 3
        success = pd.Logging(directory, '', vlog_level)
        assert success is False

    def test_vlog_level(self):
        directory = 'tests'
        vlog_level = 1
        success = Logging(
            directory, 'log_test.txt', vlog_level)
        assert pd.Logging.vlog_level == vlog_level

    def test_vlog_directory(self):
        directory = 'tests'
        vlog_level = 1
        success = pd.logging.init_logging(
            directory, 'log_test.txt', vlog_level)
        assert pd.Logging.log_directory == 'tests/'



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

from setuptools import setup, find_packages
import os


def read(fname):
    return open(os.path.join(os.path.dirname(__file__), fname)).read()


requirements = []

setup_requirements = []

test_requirements = []

setup(
    author="Chinmay Shah",
    author_email='chinmayshah3899@gmail.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    description="Python API for Google's Differential Privacy library",
    install_requires=requirements,
    license="Apache-2.0",
    long_description=read("README.md"),
    long_description_content_type="text/markdown",
    include_package_data=True,
    keywords='pydp',
    name='python-dp',
    package_data={
        'pydp': ['pydp.so'],
    },
    packages=find_packages(),  # need to check this
    setup_requires=setup_requirements,
    test_suite='tests',
    tests_require=test_requirements,
    url='https://github.com/OpenMined/PyDP',
    version='0.1.0',
    zip_safe=False,
)
